@@ -10,6 +10,7 @@ import sys
 from colorama import Fore
 
 import dfetch.commands.check
+import dfetch.commands.environment
 import dfetch.commands.init
 import dfetch.commands.update
 import dfetch.commands.validate
@@ -31,6 +32,7 @@ def create_parser() -> argparse.ArgumentParser:
 
     dfetch.commands.init.Init.create_menu(subparsers)
     dfetch.commands.check.Check.create_menu(subparsers)
+    dfetch.commands.environment.Environment.create_menu(subparsers)
     dfetch.commands.update.Update.create_menu(subparsers)
     dfetch.commands.validate.Validate.create_menu(subparsers)
 
