@@ -1,6 +1,7 @@
 """SVN specific implementation."""
 
 import os
+import logging
 from typing import Dict, Tuple
 
 from dfetch.project.vcs import VCS
@@ -20,6 +21,15 @@ class SvnRepo(VCS):
         except SubprocessCommandError:
             return False
 
+    @staticmethod
+    def list_tool_info(logger: logging.Logger) -> None:
+        """Print out version information."""
+        result = run_on_cmdline(logger, "svn --version")
+
+        first_line = result.stdout.decode().split("\n")[0]
+        tool, version = first_line.replace(",", "").split("version", maxsplit=1)
+        VCS._log_tool(logger, tool, version)
+
     def _check_impl(self) -> str:
         """Check if a newer version is available on the given branch."""
         info = self._get_info(self.branch)
